#ifndef OBJECTFWD_H
#define OBJECTFWD_H

//----------------------------------------------------------------------------
class ObjectBase;

class Barrier;
class BlackHole;
class Crate;
class Grenade;
class Grinder;
class MagnetBase;
class MortarBase;
class ParticleBase;
class   ExplosionParticle;
class   FountainParticle;
class   ThrustParticle;
class ParticleFountainBase;
class Platform;
class ProjectileBase;
class   GrenadeProjectile;
class   MissileProjectile;
class   ShipProjectile;
class   TankProjectile;
class   TurretProjectile;
class SAMBatteryBase;
class SwitchBase;
class Tank;
class Thorn;
class TurretBase;
class ControllableObjectBase;
class   Missile;
class   Ship;

#endif //OBJECTFWD_H
